<?php

namespace Drupal\commerce_add_to_cart_confirmation\Plugin\views\area;

use Drupal\commerce_order\Plugin\views\area\OrderTotal;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\views\Attribute\ViewsArea;
use Drupal\views\Plugin\views\argument\NumericArgument;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines an order total area handler.
 *
 * Shows the order total field with its components listed in the footer of a
 * View.
 *
 * @ingroup views_area_handlers
 */
#[ViewsArea("commerce_add_to_cart_confirmation_order_item_order_total")]
class OrderItemOrderTotal extends OrderTotal {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function render($empty = FALSE): array {
    if (!$empty || !empty($this->options['empty'])) {
      foreach ($this->view->argument as $argument) {
        // First look for an order_id argument.
        if (!$argument instanceof NumericArgument) {
          continue;
        }
        if ($argument->getField() !== 'commerce_order_item.order_item_id') {
          continue;
        }
        /** @var \Drupal\commerce_order\Entity\OrderItemInterface $order_item */
        $order_item = $this->entityTypeManager->getStorage('commerce_order_item')->load($argument->getValue());
        if (!$order_item) {
          continue;
        }
        if ($order = $order_item->getOrder()) {
          return $order->get('total_price')->view(['label' => 'inline']);
        }
      }
    }

    return [];
  }

}
